@@ -18,11 +18,10 @@
 	                [ '&&',    'AND'  ],
 			[ '||',    'OR'   ],
 	                [ '|' ,    '_CUT' ],
-			[ qr/(?<![<>])&/ , 'BGS' ],
+			[ qr/(?<![<>])&/ , 'EOS_BG' ],
 			[ '==>',   'XFW'  ],
 			[ '<==',   'XBW'  ],
 	        ],
-		no_esc_rm => 1,
 	},
-	word_gram => qr/\s+/,
+	word_gram => qr/\s/,
 };
