@@ -5,6 +5,6 @@ $VAR1 = {
 	module => 'Zoidberg::Fish::ReadLine',
 	events => {
 		readline => 'wrap_rl',
-		readmore => 'wrap_continue',
+		readmore => 'wrap_rl_more',
 	},
 }
